@@ -27,9 +27,10 @@ from planet.clients.data import (SEARCH_SORT,
                                  SEARCH_SORT_DEFAULT,
                                  STATS_INTERVAL)
 
-from planet.specs import (get_data_item_types,
-                          validate_data_item_type,
-                          SpecificationException)
+from planet.specs import (FetchBundlesSpecError,
+                          get_item_types,
+                          SpecificationException,
+                          validate_data_item_type)
 
 from . import types
 from .cmds import coro, translate_exceptions
@@ -38,9 +39,6 @@ from .options import limit, pretty
 from .session import CliSession
 from .validators import check_geom
 
-valid_item_string = "Valid entries for ITEM_TYPES: " + "|".join(
-    get_data_item_types())
-
 
 @asynccontextmanager
 async def data_client(ctx):
@@ -54,7 +52,7 @@ async def data_client(ctx):
 @click.option('-u',
               '--base-url',
               default=None,
-              help='Assign custom base Orders API URL.')
+              help='Assign custom base Data API URL.')
 def data(ctx, base_url):
     """Commands for interacting with the Data API"""
     ctx.obj['BASE_URL'] = base_url
@@ -79,6 +77,8 @@ def check_item_types(ctx, param, item_types) -> Optional[List[dict]]:
         return item_types
     except SpecificationException as e:
         raise click.BadParameter(str(e))
+    except FetchBundlesSpecError as e:
+        raise click.ClickException(str(e))
 
 
 def check_item_type(ctx, param, item_type) -> Optional[List[dict]]:
@@ -88,12 +88,14 @@ def check_item_type(ctx, param, item_type) -> Optional[List[dict]]:
         validate_data_item_type(item_type)
     except SpecificationException as e:
         raise click.BadParameter(str(e))
+    except FetchBundlesSpecError as e:
+        raise click.ClickException(str(e))
 
     return item_type
 
 
 def check_search_id(ctx, param, search_id) -> str:
-    """Ensure search id is a valix hex string"""
+    """Ensure search id is a valid hex string"""
     try:
         _ = DataClient._check_search_id(search_id)
     except exceptions.ClientError as e:
@@ -274,7 +276,7 @@ def filter(ctx,
     echo_json(filt, pretty)
 
 
-@data.command(epilog=valid_item_string)  # type: ignore
+@data.command()  # type: ignore
 @click.pass_context
 @translate_exceptions
 @coro
@@ -320,7 +322,7 @@ async def search(ctx, item_types, geom, filter, limit, name, sort, pretty):
             echo_json(item, pretty)
 
 
-@data.command(epilog=valid_item_string)  # type: ignore
+@data.command()  # type: ignore
 @click.pass_context
 @translate_exceptions
 @coro
@@ -417,7 +419,7 @@ async def search_run(ctx, search_id, sort, limit, pretty):
             echo_json(item, pretty)
 
 
-@data.command(epilog=valid_item_string)  # type: ignore
+@data.command()  # type: ignore
 @click.pass_context
 @translate_exceptions
 @coro
@@ -477,7 +479,7 @@ async def search_delete(ctx, search_id):
         await cl.delete_search(search_id)
 
 
-@data.command(epilog=valid_item_string)  # type: ignore
+@data.command()  # type: ignore
 @click.pass_context
 @translate_exceptions
 @coro
@@ -526,7 +528,7 @@ async def search_update(ctx,
         echo_json(items, pretty)
 
 
-@data.command(epilog=valid_item_string)  # type: ignore
+@data.command()  # type: ignore
 @click.pass_context
 @translate_exceptions
 @coro
@@ -588,7 +590,7 @@ async def asset_download(ctx,
             cl.validate_checksum(asset, path)
 
 
-@data.command(epilog=valid_item_string)  # type: ignore
+@data.command()  # type: ignore
 @click.pass_context
 @translate_exceptions
 @coro
@@ -602,7 +604,7 @@ async def asset_activate(ctx, item_type, item_id, asset_type):
         await cl.activate_asset(asset)
 
 
-@data.command(epilog=valid_item_string)  # type: ignore
+@data.command()  # type: ignore
 @click.pass_context
 @translate_exceptions
 @coro
@@ -636,19 +638,85 @@ async def asset_wait(ctx, item_type, item_id, asset_type, delay, max_attempts):
     click.echo(status)
 
 
-# @data.command()
-# @click.pass_context
-# @translate_exceptions
-# @coro
-# @click.argument("item_type")
-# @click.argument("item_id")
-# @click.argument("asset_type_id")
-# @pretty
-# async def asset_get(ctx, item_type, item_id, asset_type_id, pretty):
-#     """Get an item asset."""
-#     async with data_client(ctx) as cl:
-#         asset = await cl.get_asset(item_type, item_id, asset_type_id)
-#     echo_json(asset, pretty)
+@data.command()  # type: ignore
+@click.pass_context
+@translate_exceptions
+@coro
+@click.argument("item_type")
+@click.argument("item_id")
+@click.argument("asset_type_id")
+async def asset_get(ctx, item_type, item_id, asset_type_id):
+    """Get an item asset."""
+    async with data_client(ctx) as cl:
+        asset = await cl.get_asset(item_type, item_id, asset_type_id)
+        echo_json(asset, pretty)
 
-# TODO: search_run()".
-# TODO: item_get()".
+
+@data.command()  # type: ignore
+@click.pass_context
+@translate_exceptions
+@coro
+@click.argument("item_type", type=str, callback=check_item_type)
+@click.argument("item_id")
+async def asset_list(ctx, item_type, item_id):
+    """List item assets."""
+    async with data_client(ctx) as cl:
+        item_assets = await cl.list_item_assets(item_type, item_id)
+        echo_json(item_assets, pretty)
+
+
+@data.command()  # type: ignore
+@click.pass_context
+@translate_exceptions
+@coro
+@click.argument("item_type", type=str, callback=check_item_type)
+@click.argument("item_id")
+async def item_get(ctx, item_type, item_id):
+    """Get an item."""
+    async with data_client(ctx) as cl:
+        item = await cl.get_item(item_type, item_id)
+        echo_json(item, pretty)
+
+
+@data.command()  # type: ignore
+@click.pass_context
+@translate_exceptions
+@coro
+@click.argument("item_type", type=str, callback=check_item_type)
+@click.argument("item_id")
+@click.option("--geom",
+              type=types.Geometry(),
+              callback=check_geom,
+              required=True,
+              help="""Either a GeoJSON or a Features API reference""")
+@click.option('--mode',
+              type=str,
+              required=False,
+              help="""Method used for coverage calculation.
+    'UDM2': activates UDM2 asset for accurate coverage, may take time.
+    'estimate': provides a quick rough estimate without activation""")
+@click.option('--band',
+              type=str,
+              required=False,
+              help="""Specific band to extract from UDM2
+              (e.g., 'clear', 'cloud', 'snow_ice').
+              For full details, refer to the UDM2 product specifications.""")
+async def item_coverage(ctx, item_type, item_id, geom, mode, band):
+    """Get item clear coverage."""
+    async with data_client(ctx) as cl:
+        item_assets = await cl.get_item_coverage(item_type,
+                                                 item_id,
+                                                 geom,
+                                                 mode,
+                                                 band)
+        echo_json(item_assets, pretty)
+
+
+@data.command()  # type: ignore
+@click.pass_context
+@translate_exceptions
+def item_types(ctx):
+    """Show valid item types."""
+    click.echo("Valid item types:")
+    for it in get_item_types():
+        click.echo(f"- {it}")
