@@ -15,6 +15,7 @@
 from contextlib import asynccontextmanager
 import logging
 from pathlib import Path
+from typing import List, Optional
 
 import click
 
@@ -26,10 +27,52 @@ from ..order_request import sentinel_hub
 from .io import echo_json
 from .options import limit, pretty
 from .session import CliSession
+from ..specs import (FetchBundlesSpecError,
+                     get_bundle_names,
+                     get_item_types,
+                     SpecificationException,
+                     validate_bundle,
+                     validate_data_item_type)
 
 LOGGER = logging.getLogger(__name__)
 
 
+def check_item_type(ctx, param, item_type):
+    """Validates the item type provided by comparing it to all supported
+    item types."""
+    try:
+        validate_data_item_type(item_type)
+        return item_type
+    except SpecificationException as e:
+        raise click.BadParameter(str(e))
+    except FetchBundlesSpecError as e:
+        raise click.ClickException(str(e))
+
+
+def check_bundle(ctx, param, bundle) -> Optional[List[dict]]:
+    """Validates the bundle provided by comparing it to all supported
+    bundles."""
+
+    # Get the value of item_type from the context
+    item_type = ctx.params.get('item_type')
+    if not item_type:
+        raise click.BadParameter("Item type is required to validate a bundle.")
+
+    if bundle is None:
+        return bundle
+
+    bundles = bundle.split(",")
+    for b in bundles:
+        try:
+            validate_bundle(item_type, b)
+        except SpecificationException as e:
+            raise click.BadParameter(str(e))
+        except FetchBundlesSpecError as e:
+            raise click.ClickException(str(e))
+
+    return bundle
+
+
 @asynccontextmanager
 async def orders_client(ctx):
     base_url = ctx.obj['BASE_URL']
@@ -268,6 +311,12 @@ async def download(ctx, order_id, overwrite, directory, checksum):
               default=None,
               help='Collection ID for Sentinel Hub hosting. '
               'If omitted, a new collection will be created.')
+@click.option(
+    '--create-configuration',
+    is_flag=True,
+    default=False,
+    help='Automatically create a layer configuration for your collection. '
+    'If omitted, no configuration will be created.')
 @pretty
 async def create(ctx, request, pretty, **kwargs):
     """Create an order.
@@ -278,17 +327,21 @@ async def create(ctx, request, pretty, **kwargs):
     REQUEST is the full description of the order to be created. It must be JSON
     and can be specified a json string, filename, or '-' for stdin.
 
-    Other flag options are hosting and collection_id. The hosting flag
-    specifies the hosting type, and the collection_id flag specifies the
-    collection ID for Sentinel Hub. If the collection_id is omitted, a new
-    collection will be created.
+    Other flag options are hosting, collection_id, and create_configuration.
+    The hosting flag specifies the hosting type, the collection_id flag specifies the
+    collection ID for Sentinel Hub, and the create_configuration flag specifies
+    whether or not to create a layer configuration for your collection. If the
+    collection_id is omitted, a new collection will be created. If the
+    create_configuration flag is omitted, no configuration will be created. The
+    collection_id flag and create_configuration flag cannot be used together.
     """
 
     hosting = kwargs.get('hosting')
     collection_id = kwargs.get('collection_id')
+    create_configuration = bool(kwargs.get('create_configuration', False))
 
     if hosting == "sentinel_hub":
-        request["hosting"] = sentinel_hub(collection_id)
+        request["hosting"] = sentinel_hub(collection_id, create_configuration)
 
     async with orders_client(ctx) as cl:
         order = await cl.create_order(request)
@@ -304,13 +357,20 @@ async def create(ctx, request, pretty, **kwargs):
 @click.option('--item-type',
               required=True,
               help='Item type for requested item ids.',
-              type=click.Choice(planet.specs.get_item_types(),
-                                case_sensitive=False))
+              type=str,
+              callback=check_item_type)
 @click.option('--bundle',
               required=True,
-              help='Asset type for the item.',
-              type=click.Choice(planet.specs.get_product_bundles(),
-                                case_sensitive=False))
+              help='Bundle type for the item.',
+              type=str,
+              callback=check_bundle)
+@click.option(
+    '--fallback-bundle',
+    required=False,
+    help="""Fallback bundle type(s) for the item if bundle is not available.
+    Multiple fallback bundles can be specified as a comma-separated string.""",
+    type=str,
+    callback=check_bundle)
 @click.option('--name',
               required=True,
               help='Order name. Does not need to be unique.',
@@ -360,13 +420,19 @@ async def create(ctx, request, pretty, **kwargs):
               type=click.Choice(['sentinel_hub']),
               help='Hosting for data delivery. '
               'Currently, only "sentinel_hub" is supported.')
-@click.option('--collection_id',
+@click.option('--collection-id',
               help='Collection ID for Sentinel Hub hosting. '
               'If omitted, a new collection will be created.')
+@click.option(
+    '--create-configuration',
+    is_flag=True,
+    help='Automatically create a layer configuration for your collection. '
+    'If omitted, no configuration will be created.')
 @pretty
 async def request(ctx,
                   item_type,
                   bundle,
+                  fallback_bundle,
                   name,
                   ids,
                   clip,
@@ -379,6 +445,7 @@ async def request(ctx,
                   stac,
                   hosting,
                   collection_id,
+                  create_configuration,
                   pretty):
     """Generate an order request.
 
@@ -389,7 +456,10 @@ async def request(ctx,
     IDs is one or more comma-separated item IDs.
     """
     try:
-        product = planet.order_request.product(ids, bundle, item_type)
+        product = planet.order_request.product(ids,
+                                               bundle,
+                                               item_type,
+                                               fallback_bundle)
     except planet.specs.SpecificationException as e:
         raise click.BadParameter(e)
 
@@ -416,13 +486,35 @@ async def request(ctx,
     else:
         stac_json = {}
 
-    request = planet.order_request.build_request(name,
-                                                 products=[product],
-                                                 delivery=delivery,
-                                                 notifications=notifications,
-                                                 tools=tools,
-                                                 stac=stac_json,
-                                                 hosting=hosting,
-                                                 collection_id=collection_id)
+    request = planet.order_request.build_request(
+        name,
+        products=[product],
+        delivery=delivery,
+        notifications=notifications,
+        tools=tools,
+        stac=stac_json,
+        hosting=hosting,
+        collection_id=collection_id,
+        create_configuration=create_configuration)
 
     echo_json(request, pretty)
+
+
+@orders.command()  # type: ignore
+@click.pass_context
+@translate_exceptions
+def item_types(ctx):
+    """Show valid item types for ordering."""
+    click.echo("Valid item types:")
+    for it in get_item_types():
+        click.echo(f"- {it}")
+
+
+@orders.command()  # type: ignore
+@click.pass_context
+@translate_exceptions
+def bundles(ctx):
+    """Show valid bundle names for ordering."""
+    click.echo("Valid bundles:")
+    for it in get_bundle_names():
+        click.echo(f"- {it}")
