@@ -17,14 +17,16 @@ import hashlib
 import logging
 from pathlib import Path
 import time
-from typing import Any, AsyncIterator, Awaitable, Callable, Dict, List, Optional, TypeVar
+from typing import Any, AsyncIterator, Callable, Dict, List, Optional, TypeVar, Union
 import uuid
 
+from planet.clients.base import _BaseClient
+
 from ..data_filter import empty_filter
 from .. import exceptions
 from ..constants import PLANET_BASE_URL
 from ..http import Session
-from ..models import Paged, StreamingBody
+from ..models import GeojsonLike, Paged, StreamingBody
 from ..specs import validate_data_item_type
 from ..geojson import as_geom_or_ref
 
@@ -67,7 +69,7 @@ class Searches(Paged):
     ITEMS_KEY = 'searches'
 
 
-class DataClient:
+class DataClient(_BaseClient):
     """High-level asynchronous access to Planet's data API.
 
     Example:
@@ -92,15 +94,7 @@ class DataClient:
             base_url: The base URL to use. Defaults to production data API
                 base url.
         """
-        self._session = session
-
-        self._base_url = base_url or BASE_URL
-        if self._base_url.endswith('/'):
-            self._base_url = self._base_url[:-1]
-
-    def _call_sync(self, f: Awaitable[T]) -> T:
-        """block on an async function call, using the call_sync method of the session"""
-        return self._session._call_sync(f)
+        super().__init__(session, base_url or BASE_URL)
 
     @staticmethod
     def _check_search_id(sid):
@@ -117,13 +111,14 @@ class DataClient:
     def _item_url(self, item_type, item_id):
         return f'{self._base_url}/item-types/{item_type}/items/{item_id}'
 
-    async def search(self,
-                     item_types: List[str],
-                     search_filter: Optional[dict] = None,
-                     name: Optional[str] = None,
-                     sort: Optional[str] = None,
-                     limit: int = 100,
-                     geometry: Optional[dict] = None) -> AsyncIterator[dict]:
+    async def search(
+            self,
+            item_types: List[str],
+            search_filter: Optional[dict] = None,
+            name: Optional[str] = None,
+            sort: Optional[str] = None,
+            limit: int = 100,
+            geometry: Optional[GeojsonLike] = None) -> AsyncIterator[dict]:
         """Iterate over results from a quick search.
 
         Quick searches are saved for a short period of time (~month). The
@@ -140,7 +135,7 @@ class DataClient:
             search_filter: Structured search criteria to apply. If None,
                 no search criteria is applied.
             sort: Field and direction to order results by. Valid options are
-            given in SEARCH_SORT.
+                given in SEARCH_SORT.
             name: The name of the saved search.
             limit: Maximum number of results to return. When set to 0, no
                 maximum is applied.
@@ -185,7 +180,7 @@ class DataClient:
         search_filter: dict,
         name: str,
         enable_email: bool = False,
-        geometry: Optional[dict] = None,
+        geometry: Optional[Union[dict, str]] = None,
     ) -> dict:
         """Create a new saved structured item search.
 
@@ -236,13 +231,14 @@ class DataClient:
                                                json=request)
         return response.json()
 
-    async def update_search(self,
-                            search_id: str,
-                            item_types: List[str],
-                            search_filter: dict,
-                            name: str,
-                            enable_email: bool = False,
-                            geometry: Optional[dict] = None) -> dict:
+    async def update_search(
+            self,
+            search_id: str,
+            item_types: List[str],
+            search_filter: dict,
+            name: str,
+            enable_email: bool = False,
+            geometry: Optional[Union[dict, str]] = None) -> dict:
         """Update an existing saved search.
 
         Parameters:
@@ -366,7 +362,7 @@ class DataClient:
         Parameters:
             search_id: Stored search identifier.
             sort: Field and direction to order results by. Valid options are
-            given in SEARCH_SORT.
+                given in SEARCH_SORT.
             limit: Maximum number of results to return. When set to 0, no
                 maximum is applied.
 
@@ -432,6 +428,63 @@ class DataClient:
                                                json=request)
         return response.json()
 
+    async def get_item(self, item_type_id: str, item_id: str) -> dict:
+        """Get an item by item_type_id and item_id.
+
+        Parameters:
+            item_type_id: Item type identifier.
+            item_id: Item identifier.
+
+        Returns:
+            Description of an item.
+
+        Raises:
+            planet.exceptions.APIError: On API error.
+        """
+        url = self._item_url(item_type_id, item_id)
+
+        response = await self._session.request(method="GET", url=url)
+        return response.json()
+
+    async def get_item_coverage(
+        self,
+        item_type_id: str,
+        item_id: str,
+        geometry: GeojsonLike,
+        mode: Optional[str] = None,
+        band: Optional[str] = None,
+    ) -> dict:
+        """Estimate the clear coverage over an item within a custom AOI
+
+        Parameters:
+            item_type_id: Item type identifier.
+            item_id: Item identifier.
+            geometry: A feature reference or a GeoJSON
+            mode: Method used for coverage calculation
+            band: Specific band to extract from UDM2
+
+        Returns:
+            Description of the clear coverage for the provided AOI within the scene.
+
+        Raises:
+            planet.exceptions.APIError: On API error.
+        """
+        url = f"{self._item_url(item_type_id, item_id)}/coverage"
+
+        params = {}
+        if mode is not None:
+            params["mode"] = mode
+        if band is not None:
+            params["band"] = band
+
+        request_json = {'geometry': as_geom_or_ref(geometry)}
+
+        response = await self._session.request(method="POST",
+                                               url=url,
+                                               json=request_json,
+                                               params=params)
+        return response.json()
+
     async def list_item_assets(self, item_type_id: str, item_id: str) -> dict:
         """List all assets available for an item.
 
@@ -472,7 +525,7 @@ class DataClient:
         Raises:
             planet.exceptions.APIError: On API error.
             planet.exceptions.ClientError: If asset type identifier is not
-            valid.
+                valid.
         """
         item_type_id = validate_data_item_type(item_type_id)
         assets = await self.list_item_assets(item_type_id, item_id)
@@ -495,7 +548,7 @@ class DataClient:
         Raises:
             planet.exceptions.APIError: On API error.
             planet.exceptions.ClientError: If asset description is not
-            valid.
+                valid.
         """
         try:
             status = asset['status']
@@ -611,7 +664,7 @@ class DataClient:
         Raises:
             planet.exceptions.APIError: On API error.
             planet.exceptions.ClientError: If asset is not active or asset
-            description is not valid.
+                description is not valid.
         """
         try:
             location = asset['location']
