@@ -1,10 +1,11 @@
 """Planet Subscriptions API Python client."""
 
 import logging
-from typing import AsyncIterator, Awaitable, Dict, Optional, Sequence, TypeVar, Union
+from typing import Any, AsyncIterator, Dict, Optional, Sequence, TypeVar, List
 
 from typing_extensions import Literal
 
+from planet.clients.base import _BaseClient
 from planet.exceptions import APIError, ClientError
 from planet.http import Session
 from planet.models import Paged
@@ -17,7 +18,7 @@ LOGGER = logging.getLogger()
 T = TypeVar("T")
 
 
-class SubscriptionsClient:
+class SubscriptionsClient(_BaseClient):
     """A Planet Subscriptions Service API 1.0.0 client.
 
     The methods of this class forward request parameters to the
@@ -55,29 +56,21 @@ class SubscriptionsClient:
             base_url: The base URL to use. Defaults to production subscriptions
                 API base url.
         """
-        self._session = session
+        super().__init__(session, base_url or BASE_URL)
 
-        self._base_url = base_url or BASE_URL
-        if self._base_url.endswith('/'):
-            self._base_url = self._base_url[:-1]
-
-    def _call_sync(self, f: Awaitable[T]) -> T:
-        """block on an async function call, using the call_sync method of the session"""
-        return self._session._call_sync(f)
-
-    async def list_subscriptions(
-            self,
-            status: Optional[Sequence[str]] = None,
-            limit: int = 100,
-            created: Optional[str] = None,
-            end_time: Optional[str] = None,
-            hosting: Optional[bool] = None,
-            name__contains: Optional[str] = None,
-            name: Optional[str] = None,
-            source_type: Optional[str] = None,
-            start_time: Optional[str] = None,
-            sort_by: Optional[str] = None,
-            updated: Optional[str] = None) -> AsyncIterator[dict]:
+    async def list_subscriptions(self,
+                                 status: Optional[Sequence[str]] = None,
+                                 limit: int = 100,
+                                 created: Optional[str] = None,
+                                 end_time: Optional[str] = None,
+                                 hosting: Optional[bool] = None,
+                                 name__contains: Optional[str] = None,
+                                 name: Optional[str] = None,
+                                 source_type: Optional[str] = None,
+                                 start_time: Optional[str] = None,
+                                 sort_by: Optional[str] = None,
+                                 updated: Optional[str] = None,
+                                 page_size: int = 500) -> AsyncIterator[dict]:
         """Iterate over list of account subscriptions with optional filtering.
 
         Note:
@@ -112,7 +105,7 @@ class SubscriptionsClient:
             updated (str): filter by updated time or interval.
             limit (int): limit the number of subscriptions in the
                 results. When set to 0, no maximum is applied.
-            TODO: user_id
+            page_size (int): number of subscriptions to return per page.
 
         Datetime args (created, end_time, start_time, updated) can either be a
         date-time or an interval, open or closed. Date and time expressions adhere
@@ -131,11 +124,13 @@ class SubscriptionsClient:
             ClientError: on a client error.
         """
 
+        # TODO from old doc string, which breaks strict document checking:
+        #    Add Parameter user_id
         class _SubscriptionsPager(Paged):
             """Navigates pages of messages about subscriptions."""
             ITEMS_KEY = 'subscriptions'
 
-        params: Dict[str, Union[str, Sequence[str], bool]] = {}
+        params: Dict[str, Any] = {}
         if created is not None:
             params['created'] = created
         if end_time is not None:
@@ -157,6 +152,8 @@ class SubscriptionsClient:
         if updated is not None:
             params['updated'] = updated
 
+        params['page_size'] = page_size
+
         try:
             response = await self._session.request(method='GET',
                                                    url=self._base_url,
@@ -200,6 +197,34 @@ class SubscriptionsClient:
             sub = resp.json()
             return sub
 
+    async def bulk_create_subscriptions(self, requests: List[dict]) -> Dict:
+        """
+        Create multiple subscriptions in bulk. Currently, the list of requests can only contain one item.
+
+        Args:
+            requests (List[dict]): A list of dictionaries where each dictionary
+                represents a subscription to be created.
+
+        Raises:
+            APIError: If the API returns an error response.
+            ClientError: If there is an issue with the client request.
+
+        Returns:
+            The response including a _links key to the list endpoint for use finding the created subscriptions.
+        """
+        try:
+            url = f'{self._base_url}/bulk'
+            resp = await self._session.request(
+                method='POST', url=url, json={'subscriptions': requests})
+        # Forward APIError. We don't strictly need this clause, but it
+        # makes our intent clear.
+        except APIError:
+            raise
+        except ClientError:  # pragma: no cover
+            raise
+        else:
+            return resp.json()
+
     async def cancel_subscription(self, subscription_id: str) -> None:
         """Cancel a Subscription.
 
@@ -337,7 +362,6 @@ class SubscriptionsClient:
                 filter out results with status not in this set.
             limit (int): limit the number of subscriptions in the
                 results. When set to 0, no maximum is applied.
-            TODO: created, updated, completed, user_id
 
         Yields:
             dict: description of a subscription results.
@@ -347,6 +371,8 @@ class SubscriptionsClient:
             ClientError: on a client error.
         """
 
+        # TODO from old doc string, which breaks strict document checking:
+        #    Add Parameters created, updated, completed, user_id
         class _ResultsPager(Paged):
             """Navigates pages of messages about subscription results."""
             ITEMS_KEY = 'results'
@@ -384,7 +410,6 @@ class SubscriptionsClient:
             subscription_id (str): id of a subscription.
             status (Set[str]): pass result with status in this set,
                 filter out results with status not in this set.
-            TODO: created, updated, completed, user_id
 
         Yields:
             str: a row from a CSV file.
@@ -393,6 +418,8 @@ class SubscriptionsClient:
             APIError: on an API server error.
             ClientError: on a client error.
         """
+        # TODO from old doc string, which breaks strict document checking:
+        #    Add Parameters created, updated, completed, user_id
         url = f'{self._base_url}/{subscription_id}/results'
         params = {'status': [val for val in status or {}], 'format': 'csv'}
 
@@ -404,3 +431,57 @@ class SubscriptionsClient:
         async with self._session.stream('GET', url, params=params) as response:
             async for line in response.aiter_lines():
                 yield line
+
+    async def get_summary(self) -> dict:
+        """Summarize the status of all subscriptions via GET.
+
+        Returns:
+            dict: subscription totals by status.
+
+        Raises:
+            APIError: on an API server error.
+            ClientError: on a client error.
+        """
+        url = f'{self._base_url}/summary'
+
+        try:
+            resp = await self._session.request(method='GET', url=url)
+        # Forward APIError. We don't strictly need this clause, but it
+        # makes our intent clear.
+        except APIError:
+            raise
+        except ClientError:  # pragma: no cover
+            raise
+        else:
+            summary = resp.json()
+            return summary
+
+    async def get_subscription_summary(
+        self,
+        subscription_id: str,
+    ) -> dict:
+        """Summarize the status of results for a single subscription via GET.
+
+        Parameters:
+            subscription_id (str): ID of the subscription to summarize.
+
+        Returns:
+            dict: result totals for the provided subscription by status.
+
+        Raises:
+            APIError: on an API server error.
+            ClientError: on a client error.
+        """
+        url = f'{self._base_url}/{subscription_id}/summary'
+
+        try:
+            resp = await self._session.request(method='GET', url=url)
+        # Forward APIError. We don't strictly need this clause, but it
+        # makes our intent clear.
+        except APIError:
+            raise
+        except ClientError:  # pragma: no cover
+            raise
+        else:
+            summary = resp.json()
+            return summary
