@@ -32,7 +32,8 @@ def build_request(name: str,
                   tools: Optional[List[dict]] = None,
                   stac: Optional[dict] = None,
                   hosting: Optional[str] = None,
-                  collection_id: Optional[str] = None) -> dict:
+                  collection_id: Optional[str] = None,
+                  create_configuration: Optional[bool] = False) -> dict:
     """Prepare an order request.
 
     ```python
@@ -66,10 +67,11 @@ def build_request(name: str,
         notifications: Specify custom notifications handling.
         order_type: Accept a partial order, indicated by 'partial'.
         tools: Tools to apply to the products. Order defines
-            the toolchain order of operatations.
+            the toolchain order of operations.
         stac: Include STAC metadata.
         hosting: A hosting destination (e.g. Sentinel Hub).
         collection_id: A Sentinel Hub collection ID.
+        create_configuration: Automatically create a layer configuration for your collection.
 
     Raises:
         planet.specs.SpecificationException: If order_type is not a valid
@@ -97,7 +99,7 @@ def build_request(name: str,
         details['metadata'] = stac
 
     if hosting == 'sentinel_hub':
-        details['hosting'] = sentinel_hub(collection_id)
+        details['hosting'] = sentinel_hub(collection_id, create_configuration)
 
     return details
 
@@ -105,7 +107,7 @@ def build_request(name: str,
 def product(item_ids: List[str],
             product_bundle: str,
             item_type: str,
-            fallback_bundle: Optional[str] = None) -> dict:
+            fallback_bundle: Optional[Union[str, List[str]]] = None) -> dict:
     """Product description for an order detail.
 
     Parameters:
@@ -113,9 +115,11 @@ def product(item_ids: List[str],
         product_bundle: Set of asset types for the catalog items.
         item_type: The class of spacecraft and processing characteristics
             for the catalog items.
-        fallback_bundle: In case product_bundle not having
+        fallback_bundle: In case of product_bundle not having
             all asset types available, which would result in failed
-            delivery, try a fallback bundle
+            delivery, try one or more fallback bundles. Multiple
+            fallback bundles may be provided as a list or a comma
+            separated string.
 
     Raises:
         planet.specs.SpecificationException: If bundle or fallback bundle
@@ -126,11 +130,13 @@ def product(item_ids: List[str],
     validated_product_bundle = specs.validate_bundle(item_type, product_bundle)
 
     if fallback_bundle is not None:
-        item_type = specs.validate_item_type(item_type)
-        validated_fallback_bundle = specs.validate_bundle(
-            item_type, fallback_bundle)
+        bundles = fallback_bundle.split(',') if isinstance(
+            fallback_bundle, str) else fallback_bundle
+        validated_bundles = []
+        for bundle in bundles:
+            validated_bundles.append(specs.validate_bundle(item_type, bundle))
         validated_product_bundle = ','.join(
-            [validated_product_bundle, validated_fallback_bundle])
+            [validated_product_bundle, ','.join(validated_bundles)])
 
     product_dict = {
         'item_ids': item_ids,
@@ -320,11 +326,77 @@ def google_earth_engine(project: str, collection: str) -> dict:
     return {'google_earth_engine': cloud_details}
 
 
+def oracle_cloud_storage(customer_access_key_id: str,
+                         customer_secret_key: str,
+                         bucket: str,
+                         region: str,
+                         namespace: str,
+                         path_prefix: Optional[str] = None) -> dict:
+    """Oracle Cloud Storage configuration.
+
+    Parameters:
+        customer_access_key_id: Customer Access Key credentials.
+        customer_secret_key: Customer Secret Key credentials.
+        bucket: The name of the bucket that will receive the order output.
+        region: The region where the bucket lives in Oracle.
+        namespace: Object Storage namespace name.
+        path_prefix: Custom string to prepend to the files delivered to the
+            bucket. A slash (/) character will be treated as a "folder".
+            Any other characters will be added as a prefix to the files.
+    """
+    cloud_details = {
+        'customer_access_key_id': customer_access_key_id,
+        'customer_secret_key': customer_secret_key,
+        'bucket': bucket,
+        'region': region,
+        'namespace': namespace
+    }
+
+    if path_prefix:
+        cloud_details['path_prefix'] = path_prefix
+
+    return {'oracle_cloud_storage': cloud_details}
+
+
+def s3_compatible(endpoint: str,
+                  bucket: str,
+                  region: str,
+                  access_key_id: str,
+                  secret_access_key: str,
+                  use_path_style: bool = False,
+                  path_prefix: Optional[str] = None) -> dict:
+    """S3 Compatible configuration.
+
+    Parameters:
+        endpoint: S3 compatible endpoint.
+        bucket: S3-compatible bucket that will receive the order output.
+        region: Region where the bucket lives in the s3 compatible service.
+        access_key_id: Access key for authentication.
+        secret_access_key: Secret key for authentication.
+        use_path_style: Use path-style addressing with bucket name in URL
+            (default is False).
+        path_prefix: Custom string to prepend to the files delivered to the
+            bucket. A slash (/) character will be treated as a "folder".
+            Any other characters will be added as a prefix to the files.
+    """
+    parameters = {
+        'endpoint': endpoint,
+        'bucket': bucket,
+        'region': region,
+        'access_key_id': access_key_id,
+        'secret_access_key': secret_access_key,
+        'use_path_style': use_path_style,
+    }
+    if path_prefix:
+        parameters['path_prefix'] = path_prefix
+    return {'s3_compatible': parameters}
+
+
 def _tool(name: str, parameters: dict) -> dict:
     """Create the API spec representation of a tool.
 
     See [Tools and Toolchains](
-    https://developers.planet.com/docs/orders/tools-toolchains/)
+    https://docs.planet.com/develop/apis/subscriptions/tools)
     for more information on available tools and tool parameters.
 
     Parameters:
@@ -373,10 +445,32 @@ def clip_tool(aoi: dict) -> dict:
     return _tool('clip', {'aoi': geom})
 
 
-def composite_tool() -> dict:
-    """Create the API spec representation of a composite tool.
+def composite_tool(group_by: Optional[str] = None) -> dict:
     """
-    return _tool('composite', {})
+    Create the API spec representation of a composite tool.
+
+    Parameters:
+        group_by: (Optional) Defines how items are grouped to create one or more composites.
+                  Supported values are:
+                  - "order": All input items are used to create a single composite output. This is the default behavior.
+                  - "strip_id": Input items are grouped by their strip_id to create multiple composites.
+
+    Returns:
+        dict: A dictionary representing the composite tool configuration.
+
+    Raises:
+        planet.exceptions.ClientError: If group_by is not one of "order" or "strip_id".
+    """
+    if group_by and group_by not in ["order", "strip_id"]:
+        raise ClientError(
+            f"Invalid group_by value: {group_by}. Must be 'order' or 'strip_id'."
+        )
+
+    parameters = {}
+    if group_by:
+        parameters['group_by'] = group_by
+
+    return _tool('composite', parameters)
 
 
 def coregister_tool(anchor_item: str) -> dict:
@@ -515,7 +609,7 @@ def band_math_tool(b1: str,
     For each band expression, the bandmath tool supports normal arithmetic
     operations and simple math operators offered in the Python numpy package.
     (For a list of supported mathematical functions, see
-    [Bandmath supported numpy math routines](https://developers.planet.com/apis/orders/bandmath-numpy-routines/)).
+    [Band Math documentation](https://docs.planet.com/develop/apis/orders/tools/#band-math)).
 
     One bandmath imagery output file is produced for each product bundle, with
     output bands derived from the band math expressions. nodata pixels are
@@ -526,7 +620,21 @@ def band_math_tool(b1: str,
     in these files.
 
     Parameters:
-        b1-b15: An expression defining how the output band should be computed.
+        b1: An expression defining how the output band should be computed.
+        b2: An expression defining how the output band should be computed.
+        b3: An expression defining how the output band should be computed.
+        b4: An expression defining how the output band should be computed.
+        b5: An expression defining how the output band should be computed.
+        b6: An expression defining how the output band should be computed.
+        b7: An expression defining how the output band should be computed.
+        b8: An expression defining how the output band should be computed.
+        b9: An expression defining how the output band should be computed.
+        b10: An expression defining how the output band should be computed.
+        b11: An expression defining how the output band should be computed.
+        b12: An expression defining how the output band should be computed.
+        b13: An expression defining how the output band should be computed.
+        b14: An expression defining how the output band should be computed.
+        b15: An expression defining how the output band should be computed.
         pixel_type: A value indicating what the output pixel type should be.
 
     Raises:
@@ -544,9 +652,12 @@ def band_math_tool(b1: str,
     return _tool('bandmath', parameters)
 
 
-def sentinel_hub(collection_id: Optional[str] = None) -> dict:
+def sentinel_hub(collection_id: Optional[str] = None,
+                 create_configuration: Optional[bool] = False) -> dict:
     """Specify a Sentinel Hub hosting destination."""
-    params = {}
+    params: Dict[str, Union[str, bool]] = {}
     if collection_id:
         params['collection_id'] = collection_id
+    if create_configuration:
+        params['create_configuration'] = create_configuration
     return {'sentinel_hub': params}
