@@ -54,6 +54,7 @@ def build_request(name: str,
                   tools: Optional[List[Mapping]] = None,
                   hosting: Optional[Union[Mapping, str]] = None,
                   collection_id: Optional[str] = None,
+                  create_configuration: Optional[bool] = False,
                   clip_to_source: Optional[bool] = False) -> dict:
     """Construct a Subscriptions API request.
 
@@ -68,15 +69,13 @@ def build_request(name: str,
         tools: Tools to apply to the products. The order of operation
             is determined by the service.
         hosting: A hosting destination e.g. Sentinel Hub.
-        clip_to_source: whether to clip to the source geometry or not
-            (the default). If True a clip configuration will be added to
-            the list of requested tools unless an existing clip tool
-            exists.  NOTE: Not all data layers support clipping, please
-            consult the Product reference before using this option.
-            NOTE: the next version of the Subscription API will remove
-            the clip tool option and always clip to the source geometry.
-            Thus this is a preview of the next API version's default
-            behavior.
+        collection_id: A Sentinel Hub collection ID.
+        create_configuration: Automatically create a layer configuration for your collection.
+        clip_to_source: Whether or not to clip to the source geometry (defaults to False). If
+            True, a clip configuration that specifies the subscription source geometry as clip
+            AOI will be added to the list of requested tools.  If True and 'clip_tool()' is
+            also specified, an exception will be raised.  If False, no clip configuration
+            will be added to the list of requested tools unless 'clip_tool()' is specified.
 
     Returns:
         dict: a representation of a Subscriptions API request for
@@ -130,10 +129,7 @@ def build_request(name: str,
 
         # If clip_to_source is True a clip configuration will be added
         # to the list of requested tools unless an existing clip tool
-        # exists. In that case an exception is raised. NOTE: the next
-        # version of the Subscription API will remove the clip tool
-        # option and always clip to the source geometry. Thus this is a
-        # preview of the next API version's default behavior.
+        # exists. In that case an exception is raised.
         if clip_to_source:
             if any(tool.get('type', None) == 'clip' for tool in tool_list):
                 raise ClientError(
@@ -155,6 +151,9 @@ def build_request(name: str,
         }
         if collection_id:
             hosting_info["parameters"]["collection_id"] = collection_id
+        if create_configuration:
+            hosting_info["parameters"][
+                "create_configuration"] = create_configuration
         details['hosting'] = hosting_info
     elif isinstance(hosting, dict):
         details['hosting'] = hosting
@@ -165,7 +164,7 @@ def build_request(name: str,
 def catalog_source(
     item_types: List[str],
     asset_types: List[str],
-    geometry: dict,
+    geometry: Union[dict, str],
     start_time: datetime,
     filter: Optional[Mapping] = None,
     end_time: Optional[datetime] = None,
@@ -188,7 +187,8 @@ def catalog_source(
             deliver if all specified asset types are published for that
             item.
         geometry: The area of interest of the subscription that will be
-            used to determine matches.
+            used to determine matches. Can be either a geojson-like dict
+            or a Features API feature reference (string)
         start_time: The start time of the subscription. This time can be
             in the past or future.
         filter: The filter criteria based on item-level metadata.
@@ -274,20 +274,20 @@ def catalog_source(
     if time_range_type:
         parameters['time_range_type'] = time_range_type
 
-    return {"type": "catalog", "parameters": parameters}
+    return {"parameters": parameters}
 
 
 def planetary_variable_source(
-    var_type: str,
+    var_type: Optional[str],
     var_id: str,
-    geometry: dict,
+    geometry: Union[dict, str],
     start_time: datetime,
     end_time: Optional[datetime] = None,
 ) -> dict:
     """Construct a Planetary Variable subscription source.
 
     Planetary Variables come in 4 types and are further subdivided
-    within these types. See [Subscribing to Planetary Variables](https://developers.planet.com/docs/subscriptions/pvs-subs/#planetary-variables-types-and-ids)
+    within these types. See [Subscribing to Planetary Variables](https://docs.planet.com/develop/apis/subscriptions/sources/#planetary-variable-and-analysis-ready-source-types)
     or the [OpenAPI spec](https://api.planet.com/subscriptions/v1/spec) for
     more details.
 
@@ -298,11 +298,13 @@ def planetary_variable_source(
 
     Parameters:
         var_type: Planetary Variable type. See documentation for all
-            available types.
+            available types.  Used to be a required parameter but
+            is now optional and can be 'None'.
         var_id: A Planetary Variable ID. See documenation for all
             available IDs.
         geometry: The area of interest of the subscription that will be
-            used to determine matches.
+            used to determine matches. May be a geojson-like dict or a
+            Features API geometry reference (string)
         start_time: The start time of the subscription. This time can be
             in the past or future.
         end_time: The end time of the subscription. This time can be in
@@ -361,7 +363,10 @@ def planetary_variable_source(
         except AttributeError:
             raise ClientError('Could not convert end_time to an iso string')
 
-    return {"type": var_type, "parameters": parameters}
+    source: dict[str, Any] = {"parameters": parameters}
+    if var_type:
+        source["type"] = var_type
+    return source
 
 
 def _datetime_to_rfc3339(value: datetime) -> str:
@@ -387,7 +392,7 @@ def amazon_s3(aws_access_key_id: str,
     Parameters:
         aws_access_key_id: S3 account access key.
         aws_secret_access_key: S3 account secret key.
-        bucket: The name of the bucket that will receive the order output.
+        bucket: The name of the bucket that will receive the subscription output.
         aws_region: The region where the bucket lives in AWS.
         path_prefix: Path prefix for deliveries.
     """
@@ -416,7 +421,7 @@ def azure_blob_storage(account: str,
         container: ABS container name.
         sas_token: Shared-Access Signature token. Token should be specified
             without a leading '?'.
-        storage_endpoint_suffix: Deliver order to a sovereign cloud. The
+        storage_endpoint_suffix: Deliver subscription to a sovereign cloud. The
             default is "core.windows.net".
         path_prefix: Path prefix for deliveries.
     """
@@ -435,6 +440,23 @@ def azure_blob_storage(account: str,
     return _delivery('azure_blob_storage', parameters)
 
 
+def google_earth_engine(project: str, collection: str,
+                        credentials: str) -> dict:
+    """Delivery to Google Earth Engine.
+
+    Parameters:
+        project: GEE project name.
+        collection: GEE Image Collection name.
+        credentials: GEE service account credentials.
+    """
+    parameters = {
+        'project': project,
+        'collection': collection,
+        'credentials': credentials
+    }
+    return _delivery('google_earth_engine', parameters)
+
+
 def google_cloud_storage(credentials: str,
                          bucket: str,
                          path_prefix: Optional[str] = None) -> dict:
@@ -467,7 +489,7 @@ def oracle_cloud_storage(customer_access_key_id: str,
     Parameters:
         customer_access_key_id: Customer Secret Key credentials.
         customer_secret_key: Customer Secret Key credentials.
-        bucket: The name of the bucket that will receive the order output.
+        bucket: The name of the bucket that will receive the subscription output.
         region: The region where the bucket lives in Oracle.
         namespace: Object Storage namespace name.
         path_prefix: Path prefix for deliveries.
@@ -486,6 +508,40 @@ def oracle_cloud_storage(customer_access_key_id: str,
     return _delivery('oracle_cloud_storage', parameters)
 
 
+def s3_compatible(endpoint: str,
+                  bucket: str,
+                  region: str,
+                  access_key_id: str,
+                  secret_access_key: str,
+                  use_path_style: bool = False,
+                  path_prefix: Optional[str] = None) -> dict:
+    """S3 Compatible configuration.
+
+    Parameters:
+        endpoint: S3 compatible endpoint.
+        bucket: S3-compatible bucket that will receive the subscription output.
+        region: Region where the bucket lives in the s3 compatible service.
+        access_key_id: Access key for authentication.
+        secret_access_key: Secret key for authentication.
+        use_path_style: Use path-style addressing with bucket name in URL
+            (default is False).
+        path_prefix: Custom string to prepend to the files delivered to the
+            bucket. A slash (/) character will be treated as a "folder".
+            Any other characters will be added as a prefix to the files.
+    """
+    parameters = {
+        'endpoint': endpoint,
+        'bucket': bucket,
+        'region': region,
+        'access_key_id': access_key_id,
+        'secret_access_key': secret_access_key,
+        'use_path_style': use_path_style,
+    }
+    if path_prefix:
+        parameters['path_prefix'] = path_prefix
+    return _delivery('s3_compatible', parameters)
+
+
 def notifications(url: str, topics: List[str]) -> dict:
     """Specify a subscriptions API notification.
 
@@ -539,7 +595,7 @@ def band_math_tool(b1: str,
     For each band expression, the bandmath tool supports normal arithmetic
     operations and simple math operators offered in the Python numpy package.
     (For a list of supported mathematical functions, see
-    [Bandmath supported numpy math routines](https://developers.planet.com/apis/orders/bandmath-numpy-routines/)).
+    [Band Math documentation](https://docs.planet.com/develop/apis/subscriptions/tools/#band-math)).
 
     One bandmath imagery output file is produced for each product bundle, with
     output bands derived from the band math expressions. nodata pixels are
@@ -550,7 +606,21 @@ def band_math_tool(b1: str,
     in these files.
 
     Parameters:
-        b1-b15: An expression defining how the output band should be computed.
+        b1: An expression defining how the output band should be computed.
+        b2: An expression defining how the output band should be computed.
+        b3: An expression defining how the output band should be computed.
+        b4: An expression defining how the output band should be computed.
+        b5: An expression defining how the output band should be computed.
+        b6: An expression defining how the output band should be computed.
+        b7: An expression defining how the output band should be computed.
+        b8: An expression defining how the output band should be computed.
+        b9: An expression defining how the output band should be computed.
+        b10: An expression defining how the output band should be computed.
+        b11: An expression defining how the output band should be computed.
+        b12: An expression defining how the output band should be computed.
+        b13: An expression defining how the output band should be computed.
+        b14: An expression defining how the output band should be computed.
+        b15: An expression defining how the output band should be computed.
         pixel_type: A value indicating what the output pixel type should be.
 
     Raises:
@@ -579,6 +649,10 @@ def clip_tool(aoi: Mapping) -> dict:
     the clip aoi is so large that full scenes may be delivered without any
     clipping, those files will not have “_clip” appended to their file name.
 
+    NOTE: To clip to the source geometry, set the 'clip_to_source' parameter
+    of 'planet.subscription_request.build_request()' to True instead of using
+    this tool.
+
     Parameters:
         aoi: GeoJSON polygon or multipolygon defining the clip area, with up to
             500 vertices. The minimum geographic area of any polygon or
@@ -588,6 +662,7 @@ def clip_tool(aoi: Mapping) -> dict:
         planet.exceptions.ClientError: If aoi is not a valid polygon or
             multipolygon.
     """
+
     valid_types = ['Polygon', 'MultiPolygon', 'ref']
 
     geom = geojson.as_geom_or_ref(dict(aoi))
@@ -673,7 +748,7 @@ def reproject_tool(projection: str,
 def toar_tool(scale_factor: int = 10000) -> dict:
     """Specify a subscriptions API reproject tool.
 
-    The toar tool supports the analytic asset type for PSScene, PSOrthoTile,
+    The toar tool supports the analytic asset type for PSScene
     and REOrthoTile item types. In addition to the analytic asset, the
     corresponding XML metadata asset type is required.
 
@@ -750,18 +825,24 @@ def _hosting(type: str, parameters: dict) -> dict:
     return {"type": type, "parameters": parameters}
 
 
-def sentinel_hub(collection_id: Optional[str]) -> dict:
+def sentinel_hub(collection_id: Optional[str],
+                 create_configuration: Optional[bool] = False) -> dict:
     """Specify a Sentinel Hub hosting destination.
 
     Requires the user to have a Sentinel Hub account linked with their Planet
-    account.  Subscriptions API will create a new collection to deliver data to
-    if collection_id is omitted from the request.
+    account. Subscriptions API will create a new collection to deliver data to
+    if collection_id is omitted from the request. Will also create a new layer
+    configuration for the collection if create_configuration is True.
+    collection_id and create_configuration are mutually exclusive in the API.
 
     Parameters:
         collection_id: Sentinel Hub collection
+        create_configuration: Automatically create a layer configuration for your collection.
     """
 
-    parameters = {}
+    parameters: Dict[str, Union[str, bool]] = {}
     if collection_id:
         parameters['collection_id'] = collection_id
+    if create_configuration:
+        parameters['create_configuration'] = create_configuration
     return _hosting("sentinel_hub", parameters)
