@@ -22,7 +22,7 @@ import logging
 import random
 import threading
 import time
-from typing import AsyncGenerator, Awaitable, Optional, TypeVar
+from typing import Any, AsyncGenerator, AsyncIterator, Awaitable, Coroutine, Iterator, Optional, TypeVar
 
 import httpx
 from typing_extensions import Literal
@@ -50,9 +50,7 @@ RETRY_EXCEPTIONS = [
 MAX_RETRIES = 5
 MAX_RETRY_BACKOFF = 64  # seconds
 
-# For how these settings were determined, see
-# https://github.com/planetlabs/planet-client-python/issues/580
-READ_TIMEOUT = 30.0
+DEFAULT_READ_TIMEOUT_SECS = 125.0
 RATE_LIMIT = 10  # per second
 MAX_ACTIVE = 50
 
@@ -167,7 +165,7 @@ class _Limiter:
                     break
                 elif now - self._last_call >= self.cadence:
                     LOGGER.debug(
-                        f'Throught throttle, delta: {now - self._last_call}')
+                        f'Through throttle, delta: {now - self._last_call}')
                     self._last_call = now
                     break
                 await asyncio.sleep(self.retry_interval)
@@ -231,11 +229,16 @@ class Session(BaseSession):
     ```
     """
 
-    def __init__(self, auth: Optional[AuthType] = None):
+    def __init__(
+        self,
+        auth: Optional[AuthType] = None,
+        read_timeout_secs: Optional[float] = None,
+    ):
         """Initialize a Session.
 
         Parameters:
             auth: Planet server authentication.
+            read_timeout_secs: Maximum time to wait for data to be received.
         """
         if auth is None:
             # Try getting credentials from environment before checking
@@ -246,8 +249,12 @@ class Session(BaseSession):
             except exceptions.PlanetError:
                 auth = Auth.from_file()
 
-        LOGGER.info(f'Session read timeout set to {READ_TIMEOUT}.')
-        timeout = httpx.Timeout(10.0, read=READ_TIMEOUT)
+        if read_timeout_secs is None:
+            read_timeout_secs = DEFAULT_READ_TIMEOUT_SECS
+
+        LOGGER.info(
+            f'Session read timeout set to {read_timeout_secs} seconds.')
+        timeout = httpx.Timeout(10.0, read=read_timeout_secs)
 
         headers = {
             'User-Agent': self._get_user_agent(), 'X-Planet-App': 'python-sdk'
@@ -275,6 +282,12 @@ class Session(BaseSession):
         self._limiter = _Limiter(rate_limit=RATE_LIMIT, max_workers=MAX_ACTIVE)
         self.outcomes: Counter[str] = Counter()
 
+        self._loop: asyncio.AbstractEventLoop = None  # type: ignore
+
+    def _init_loop(self):
+        if self._loop:
+            return
+
         # create a dedicated event loop for this httpx session.
         def _start_background_loop(loop):
             asyncio.set_event_loop(loop)
@@ -286,9 +299,26 @@ class Session(BaseSession):
                                              daemon=True)
         self._loop_thread.start()
 
-    def _call_sync(self, f: Awaitable[T]) -> T:
+    def _call_sync(self, f: Coroutine[Any, Any, T]) -> T:
+        self._init_loop()
         return asyncio.run_coroutine_threadsafe(f, self._loop).result()
 
+    def _aiter_to_iter(self, aiter: AsyncIterator[T]) -> Iterator[T]:
+        self._init_loop()
+
+        # this turns an awaitable into a coroutine - works around typing
+        # check on run_coroutine_threadsafe (which actually does check if
+        # the argument is a coroutine)
+        async def coro(a: Awaitable[T]) -> T:
+            return await a
+
+        try:
+            while True:
+                yield asyncio.run_coroutine_threadsafe(coro(aiter.__anext__()),
+                                                       self._loop).result()
+        except StopAsyncIteration:
+            pass
+
     @classmethod
     async def _raise_for_status(cls, response):
         if response.is_error:
@@ -363,7 +393,7 @@ class Session(BaseSession):
         in the threshold value being returned.
 
         Ref:
-        * https://developers.planet.com/docs/data/api-mechanics/
+        * https://docs.planet.com/develop/apis/data/#api-mechanics
         * https://cloud.google.com/iot/docs/how-tos/exponential-backoff
         """
         random_number_milliseconds = random.randint(0, 999) / 1000.0
@@ -449,7 +479,7 @@ class Session(BaseSession):
             A client instance.
 
         Raises:
-            ClientError when no such client can be had.
+            planet.exceptions.ClientError: when no such client can be had.
 
         """
         # To avoid circular dependency.
